#!/usr/bin/env python3
# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import unittest
import os

from testtools.content import text_content
from ucitests import fixtures as uci_fixtures

from ci_utils.testing import fixtures
from subunitresults import subunit_parser


class TestSubUnit(unittest.TestCase):

    def setUp(self):
        uci_fixtures.set_uniq_cwd(self)
        ds_path = os.path.join(self.uniq_dir, 'data_store')
        self.ds = fixtures.FakeDataStore(ds_path, None)
        self.addCleanup(self.ds.delete, recursive=True)

    def test_run_result(self):
        test_dir = os.path.dirname(os.path.realpath(__file__))
        subunit_file = os.path.join(test_dir, 'results_for_tests.subunit')
        success = subunit_parser.run_result(self.ds, open(subunit_file, 'rb'))
        self.assertTrue(success)

    def test_file_save_result(self):
        filename = 'foo'
        content = 'bar'
        fs_result = subunit_parser.FileSaveResult(self.ds)
        fs_result.save_file_attachments(
            filename,
            {filename: text_content(content), }
        )
        self.addCleanup(self.ds.delete_file, filename)
        file_content = self.ds.get_file(filename)

        self.assertEqual([filename], self.ds.list_files())
        self.assertEqual(content.encode('utf-8'), file_content)
        self.assertIsInstance(fs_result, subunit_parser.FileSaveResult)
